<?php
/**
 * The template for displaying the Hero Content
 *
 * @package Decree Pro
 */


if ( ! function_exists( 'decree_contact_form_display' ) ) :
	/**
	* Add Featured content.
	*
	* @uses action hook decree_before_content.
	*
	* @since Decree Pro 1.0
	*/
	function decree_contact_form_display() {
		//decree_flush_transients();
		$output = '';

		// get data value from options
		$options        = decree_get_theme_options();
		$enable         = $options['contact_form_option'];
		$content_select = $options['contact_form_type'];

		if ( decree_check_section( $enable ) ) {
			if ( ! $output = get_transient( 'decree_contact_form' ) ) {
				echo '<!-- refreshing cache -->';

				$classes[] = $content_select ;

				$output ='
					<div id="contact-page-section" class="sections ' . implode( ' ', $classes ) . '">
						<div class="wrapper">';
							// Select content
							if ( 'page' === $content_select ) {
								$output .= decree_page_contact_form( $options );
							}
							elseif ( 'custom' === $content_select ) {
								$output .= decree_custom_contact_form( $options );
							}

					$output .= '
						</div><!-- .wrapper -->
					</div><!-- #hero-section -->';
			}

			set_transient( 'decree_contact_form', $output, 86940 );
		}
		echo $output;
	}
endif;
add_action( 'decree_before_content', 'decree_contact_form_display', 100 );


if ( ! function_exists( 'decree_demo_contact_form' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @get the data value from customizer options
	 *
	 * @since Decree Pro 1.0
	 *
	 */
	function decree_demo_contact_form() {
		return '
		<article class="post-0 page type-page status-publish has-post-thumbnail hentry" id="post-0">
			<figure class="featured-image">
		    	<a href="#" rel="bookmark">
		        	<img alt="" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/about-600x400.jpg">
		        </a>
			</figure>
			<div class="entry-container">
				<div class="entry-container-wrap">
					<header class="entry-header">
						<h2 class="entry-title section-title"><a href="#">About US: Lawyer</a></h2>
					</header><!-- .entry-header -->

					<div class="entry-summary">
						<p>A lawyer is a person who practices law, as an advocate, barrister, attorney, counselor or solicitor or chartered legal executive. Working as a lawyer involves the practical application of abstract legal theories and knowledge to solve specific individualized problems, or to advance the interests of those who hire lawyers to perform legal services. <span class="more-button"><a class="button-minimal" href="#">Read More ...</a></span>
					</div><!-- .entry-summary -->
				</div><!-- .entry-container-wrap -->
			</div><!-- .entry-container -->
		</article><!-- .hentry -->';
	}
endif; // decree_demo_contact_form


if ( ! function_exists( 'decree_page_contact_form' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @param $options: decree_theme_options from customizer
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_page_contact_form( $options ) {
		$output = '';
		if ( isset( $options['contact_form_page'] ) && ! empty( $options['contact_form_page'] ) && '' !== $options['contact_form_page'] ) {
			$no_of_post = 0; // for number of posts
			$post_list  = array();// list of valid post/page ids
			$output     = '';

			$page = get_post( $options['contact_form_page'] );

			$output .= '
			<div class="section-content-wrap">
				<article id="contact-page-' . esc_attr( $options['contact_form_page'] ) . '" class="post hentry">';

			if ( $options['contact_form_enable_title'] ) {
				$output .= '
					<div class="entry-header">
						<h2 class="section-title entry-title">' . $page->post_title . '
						</h2>
					</div>';
			}

			$output .= '
					<div class="entry-content">';

			$content = apply_filters( 'the_content', $page->post_content );
			$output .= str_replace( ']]>', ']]&gt;', $content );

			$output .= '
					</div><!-- .entry-content -->
				</article><!-- .page-' . esc_attr( $options['contact_form_page'] ) . ' -->
			</div>';
		}

		return $output;
	}
endif; // decree_page_contact_form


if ( ! function_exists( 'decree_custom_contact_form' ) ) :
	/**
	 * This function to display hero posts content
	 *
	 * @get the data value from theme options
	 * @displays on the index
	 *
	 * @useage Featured Image, Title and Excerpt of Post
	 *
	 * @uses set_transient
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_custom_contact_form( $options ) {
		$output   = '';

		if ( '' !== $options['contact_form_title'] || '' !== $options['contact_form_description'] ) {
			$output .= '<div class="section-heading-wrap">';

			if ( '' !== $options['contact_form_title'] ) {
				$output .= '
				<div class="entry-header">
					<h2 class="section-title entry-title">' . $options['contact_form_title'] . '
					</h2>
				</div><!-- .entry-header -->';
			}

			if ( '' !== $options['contact_form_description'] ) {
				$output .= '
				<p>' . $options['contact_form_description'] . '</p>';
			}

			$output .= '</div><!-- .section-heading-wrap -->';
		}

		if ( '' !== $options['contact_form_content'] ) {
			$output .= '<div class="section-content-wrap shortcode">' . do_shortcode( $options['contact_form_content'] ) . '</div><!-- .section-content-wrap -->';
		}

		return $output;
	}
endif; //decree_custom_content
