<?php
/**
 * The template for Social Links in Customizer
 *
 * @package Decree Pro
 */

	// Social Icons
	$wp_customize->add_section( 'decree_social_links', array(
		'panel'    => 'decree_theme_options',
		'priority' => 700,
		'title'    => esc_html__( 'Social Links', 'decree-pro' ),
	) );

	$wp_customize->add_setting( 'decree_theme_options[social_icon_size]', array(
			'default' 			=> $defaults['social_icon_size'],
		'sanitize_callback'	=> 'absint',
	) );

	$wp_customize->add_control( 'decree_theme_options[social_icon_size]', array(
		'input_attrs' => array(
            'min'   => 10,
            'max'   => 200,
            'step'  => 5,
            'style' => 'width: 60px;'
            ),
		'label'    	=> esc_html__( 'Social Icon Size(px)', 'decree-pro' ),
		'priority'	=> '1.5',
		'section' 	=> 'decree_social_links',
		'settings'	=> 'decree_theme_options[social_icon_size]',
		'type'	   => 'number',
		)
	);

	$decree_social_icons 	=	decree_get_social_icons_list();

	foreach ( $decree_social_icons as $key => $value ){
		$description       = '';
		$sanitize_callback = 'esc_url_raw';

		if ( 'skype_link' === $key || 'handset_link' === $key || 'phone_link' === $key ) {
			// Skype, headset and phone links take plain text as input
			$sanitize_callback = 'sanitize_text_field';

			if ( 'skype_link' === $key ) {
				// Add skype description for user doc.
				$description       = esc_html__( 'Skype link can be of formats: callto://+{number} or skype:{username}?{action}. More Information in readme.txt file', 'decree-pro' );
			}
		} elseif ( 'email_link' === $key ) {
			$sanitize_callback = 'sanitize_email';
		}

		$wp_customize->add_setting( 'decree_theme_options[' . $key . ']', array(
			'sanitize_callback' => $sanitize_callback,
			'description'       => $description,
		) );

		$wp_customize->add_control( 'decree_theme_options[' . $key . ']', array(

			'label'    		=> $value['label'],
			'section'  		=> 'decree_social_links',
			'settings' 		=> 'decree_theme_options[' . $key . ']',
		) );
	}

	$wp_customize->add_section( 'decree_custom_social_links', array(
		'panel'       => 'decree_theme_options',
		'priority'    => 700,
		'description' => esc_html__( 'Save and refresh the page if No. of custom social icon is changed (Max number of icons is 10)', 'decree-pro' ),
		'panel'       => 'decree_social_links',
		'priority'    => 800,
		'title'       => esc_html__( 'Social Links Custom', 'decree-pro' ),
	) );

	$wp_customize->add_setting( 'decree_theme_options[custom_social_icons]', array(
			'default' 			=> $defaults['custom_social_icons'],
		'sanitize_callback'	=> 'decree_sanitize_number_range',
		)
	);

	$wp_customize->add_control( 'custom_social_icons', array(
		'input_attrs' => array(
            'min'   => 0,
            'max'   => 10,
            'step'  => 1,
            'style' => 'width: 45px;'
            ),
		'label'    	=> esc_html__( 'Number of Custom Social Icons', 'decree-pro' ),
		'priority'	=> '1.5',
		'section' 	=> 'decree_custom_social_links',
		'settings'	=> 'decree_theme_options[custom_social_icons]',
		'type'		=> 'number'
		)
	);

	//loop for custom social icons
	for( $i = 1; $i <= $options['custom_social_icons'] ; $i++ ){
		if( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
			$priority++;

		$wp_customize->add_setting( 'decree_theme_options[custom_social_icon_note_' . $i . ']', array(
					'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new decree_Note_Control( $wp_customize, 'custom_social_icon_note_'. $i, array(
	        'label'		=> esc_html__( 'Custom Social Icon #', 'decree-pro' ) . $i,
			'priority'	=> $priority . '.' . $i,
	        'section'  	=> 'decree_custom_social_links',
	        'settings'	=> 'decree_theme_options[custom_social_icon_note_' . $i . ']',
	        'type'     	=> 'description',
   		) ) );

   		$wp_customize->add_setting( 'decree_theme_options[custom_social_icon_title_' . $i . ']', array(
					'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control(  'decree_theme_options[custom_social_icon_title_' . $i . ']', array(
			'label'		=> esc_html__( 'Title', 'decree-pro' ),
			'priority'	=> $priority . '.' .$i .$i,
			'section'   => 'decree_custom_social_links',
			'settings'  => 'decree_theme_options[custom_social_icon_title_' . $i . ']',
		) );

		$wp_customize->add_setting( 'decree_theme_options[custom_social_icon_image_' . $i . ']', array(
					'sanitize_callback'	=> 'decree_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'custom_social_icon_image_'. $i , array(
			'label'		=> esc_html__( 'Image', 'decree-pro' ),
	        'priority'	=> $priority . '.' . $i .$i .$i,
			'section'   => 'decree_custom_social_links',
	        'settings'  => 'decree_theme_options[custom_social_icon_image_' . $i . ']',
		) ) );

   		$wp_customize->add_setting( 'decree_theme_options[custom_social_icon_image_hover_' . $i . ']', array(
					'sanitize_callback'	=> 'decree_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'custom_social_icon_image_hover_'. $i , array(
			'label'		=> esc_html__( 'Hover Image(Optional)', 'decree-pro' ),
	        'priority'	=> $priority . '.' . $i .$i . $i  .$i,
			'section'   => 'decree_custom_social_links',
	        'settings'  => 'decree_theme_options[custom_social_icon_image_hover_' . $i . ']',
		) ) );

		$wp_customize->add_setting( 'decree_theme_options[custom_social_icon_link_' . $i . ']', array(
					'sanitize_callback'	=> 'esc_url_raw',
		) );

		$wp_customize->add_control(  'decree_theme_options[custom_social_icon_link_' . $i . ']', array(
			'label'		=> esc_html__( 'Link', 'decree-pro' ),
	        'priority'	=> $priority . '.' .$i . $i  . $i  .$i .$i,
			'section'   => 'decree_custom_social_links',
	        'settings'  => 'decree_theme_options[custom_social_icon_link_' . $i . ']',
		) );
	}
	// Social Icons End
