<?php
/**
* The template for adding additional theme options in Customizer
*
 * @package Decree Pro
*/

$wp_customize->add_panel( 'decree_theme_options', array(
	'description' => esc_html__( 'Basic theme Options', 'decree-pro' ),
	'priority'    => 200,
	'title'       => esc_html__( 'Theme Options', 'decree-pro' ),
) );

// Breadcrumb Option
$wp_customize->add_section( 'decree_breadcrumb_options', array(
	'description' => esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'decree-pro' ),
	'panel'       => 'decree_theme_options',
	'title'       => esc_html__( 'Breadcrumb Options', 'decree-pro' ),
	'priority'    => 201,
) );

$wp_customize->add_setting( 'decree_theme_options[breadcrumb_option]', array(
	'default'			=> $defaults['breadcrumb_option'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[breadcrumb_option]', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb', 'decree-pro' ),
	'section'  => 'decree_breadcrumb_options',
	'settings' => 'decree_theme_options[breadcrumb_option]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[breadcrumb_on_homepage]', array(
	'default'			=> $defaults['breadcrumb_on_homepage'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[breadcrumb_on_homepage]', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb on Homepage', 'decree-pro' ),
	'section'  => 'decree_breadcrumb_options',
	'settings' => 'decree_theme_options[breadcrumb_on_homepage]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[breadcrumb_seperator]', array(
	'default'			=> $defaults['breadcrumb_seperator'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'decree_theme_options[breadcrumb_seperator]', array(
	'input_attrs' => array(
			'style' => 'width: 40px;'
		),
	'label'    	=> esc_html__( 'Separator between Breadcrumbs', 'decree-pro' ),
	'section' 	=> 'decree_breadcrumb_options',
	'settings' 	=> 'decree_theme_options[breadcrumb_seperator]',
	'type'     	=> 'text'
	)
);
// Breadcrumb Option End

// Comment Option
$wp_customize->add_section( 'decree_comment_option', array(
	'description'	=> esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'decree-pro' ),
	'panel' 		=> 'decree_theme_options',
	'priority'		=> 202,
	'title'   		=> esc_html__( 'Comment Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[comment_option]', array(
	'default'			=> $defaults['comment_option'],
	'sanitize_callback' => 'decree_sanitize_select',
) );


$wp_customize->add_control( 'decree_theme_options[comment_option]', array(
		'choices'  	=> decree_comment_options(),
		'label'		=> esc_html__( 'Comment Option', 'decree-pro' ),
		'priority'	=> 1,
		'section'   => 'decree_comment_option',
		'settings'  => 'decree_theme_options[comment_option]',
		'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[disable_notes]', array(
	'default'			=> $defaults['disable_notes'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[disable_notes]', array(
	'label'		=> esc_html__( 'Check to Disable Notes', 'decree-pro' ),
	'section'   => 'decree_comment_option',
	'settings'  => 'decree_theme_options[disable_notes]',
	'type'		=> 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[disable_website_field]', array(
	'default'			=> $defaults['disable_website_field'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[disable_website_field]', array(
	'label'		=> esc_html__( 'Check to Disable Website Field', 'decree-pro' ),
	'section'   => 'decree_comment_option',
	'settings'  => 'decree_theme_options[disable_website_field]',
	'type'		=> 'checkbox',
) );
// Comment End

// Excerpt Options
$wp_customize->add_section( 'decree_excerpt_options', array(
	'panel'  	=> 'decree_theme_options',
	'priority' 	=> 204,
	'title'    	=> esc_html__( 'Excerpt Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[excerpt_length]', array(
	'default'			=> $defaults['excerpt_length'],
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'decree_theme_options[excerpt_length]', array(
	'description' => __('Excerpt length. Default is 30 words', 'decree-pro'),
	'input_attrs' => array(
		'min'   => 10,
		'max'   => 200,
		'step'  => 5,
		'style' => 'width: 60px;'
		),
	'label'    => esc_html__( 'Excerpt Length (words)', 'decree-pro' ),
	'section'  => 'decree_excerpt_options',
	'settings' => 'decree_theme_options[excerpt_length]',
	'type'	   => 'number',
	)
);

$wp_customize->add_setting( 'decree_theme_options[excerpt_more_text]', array(
	'default'			=> $defaults['excerpt_more_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'decree_theme_options[excerpt_more_text]', array(
	'label'    => esc_html__( 'Read More Text', 'decree-pro' ),
	'section'  => 'decree_excerpt_options',
	'settings' => 'decree_theme_options[excerpt_more_text]',
	'type'	   => 'text',
) );
// Excerpt Options End

// Feed Redirect
$wp_customize->add_section( 'decree_feed_redirect', array(
	'panel'			=> 'decree_theme_options',
	'description'	=> esc_html__( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'decree-pro' ),
	'priority' 		=> 205,
	'title'    		=> esc_html__( 'Feed Redirect', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[feed_redirect]', array(
	'default'			=> $defaults['feed_redirect'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'decree_theme_options[feed_redirect]', array(
	'label'    => esc_html__( 'Feed Redirect', 'decree-pro' ),
	'section'  => 'decree_feed_redirect',
	'settings' => 'decree_theme_options[feed_redirect]',
	'type'	   => 'text',
) );
// Feed Redirect End

// Font Family Options
$wp_customize->add_section( 'decree_font_family', array(
	'panel'  => 'decree_theme_options',
	'priority'	=> 206,
	'title'    	=> esc_html__( 'Font Family Options', 'decree-pro' ),
) );

$avaliable_fonts = decree_avaliable_fonts();

$choices = array();

foreach ( $avaliable_fonts as $avaliable_font ) {
	$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
}

$font_family_options =	array(
	'title_font' 		=> esc_html__( 'Site Title Font Family', 'decree-pro' ),
	'body_font' 		=> esc_html__( 'Default Font Family', 'decree-pro' ),
	'tagline_font' 		=> esc_html__( 'Site Tagline Font Family', 'decree-pro' ),
	'menu_font' 		=> esc_html__( 'Menu Font Family', 'decree-pro' ),
	'content_title_font'=> esc_html__( 'Content Title Font Family', 'decree-pro' ),
	'content_font' 		=> esc_html__( 'Content Body Font Family', 'decree-pro' ),
	'headings_font' 	=> esc_html__( 'Headings Tags from h1 to h6 Font Family', 'decree-pro' )
);

foreach ( $font_family_options as $key => $font_family_option ) {
	$wp_customize->add_setting( 'decree_theme_options['. $key . ']', array(
		'default'			=> $defaults[ $key ],
		'sanitize_callback' => 'decree_sanitize_select',
	) );

	$wp_customize->add_control( 'decree_theme_options['. $key . ']', array(
		'choices'  => $choices,
		'label'    => $font_family_option,
		'section'  => 'decree_font_family',
		'settings' => 'decree_theme_options['. $key . ']',
		'type'	   => 'select',
	) );
}

$wp_customize->add_setting( 'decree_theme_options[reset_typography]', array(
	'default'			=> $defaults['reset_typography'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'decree_theme_options[reset_typography]', array(
	'label'		=> esc_html__( 'Check to reset fonts', 'decree-pro' ),
	'section'	=> 'decree_font_family',
	'settings'	=> 'decree_theme_options[reset_typography]',
	'type'		=> 'checkbox',
) );
// Font Family Options End

// Footer Editor Options
$wp_customize->add_section( 'decree_footer_options', array(
	'description'	=> esc_html__( 'You can either add html or plain text', 'decree-pro'),
	'panel'  => 'decree_theme_options',
	'priority' 		=> 207,
	'title'    		=> esc_html__( 'Footer Editor Options', 'decree-pro' ),
) );


$wp_customize->add_setting( 'decree_theme_options[footer_content]', array(
	'default'			=> $defaults['footer_content'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[footer_content]', array(
		'description' 	=> esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'decree-pro' ),
		'label'		=> esc_html__( 'Footer Content', 'decree-pro' ),
		'priority'	=> 1,
		'section'   => 'decree_footer_options',
		'settings'  => 'decree_theme_options[footer_content]',
		'type'		=> 'textarea',
) );

$wp_customize->add_setting( 'decree_theme_options[reset_footer_content]', array(
	'default'			=> $defaults['reset_footer_content'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'decree_theme_options[reset_footer_content]', array(
	'label'		=> esc_html__( 'Check to reset Footer Content', 'decree-pro' ),
	'priority'	=> 3,
	'settings'	=> 'decree_theme_options[reset_footer_content]',
	'section'	=> 'decree_footer_options',
	'type'		=> 'checkbox',
) );
// Footer Options End

// Header Right Sidebar Option
$wp_customize->add_section( 'decree_header_right', array(
	'panel'    => 'decree_theme_options',
	'priority' => 208,
	'title'    => esc_html__( 'Header Right Sidebar Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[disable_header_right_sidebar]', array(
	'default'			=> $defaults['disable_header_right_sidebar'],
	'sanitize_callback' => 'decree_sanitize_checkbox'
) );

$wp_customize->add_control( 'decree_theme_options[disable_header_right_sidebar]', array(
	'label'    	=> esc_html__( 'Check to disable Header Right Sidebar', 'decree-pro' ),
	'section'  	=> 'decree_header_right',
	'settings' 	=> 'decree_theme_options[disable_header_right_sidebar]',
	'type'     	=> 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[header_right_call_text]', array(
	'default'           => $defaults['header_right_call_text'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[header_right_call_text]' , array(
		'description' => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
		'label'       => esc_html__( 'Call Text', 'decree-pro' ),
		'section'     => 'decree_header_right',
		'settings'    => 'decree_theme_options[header_right_call_text]',
	)
);

$wp_customize->add_setting( 'decree_theme_options[header_right_call_number]', array(
	'default'			=> $defaults['header_right_call_number'],
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[header_right_call_number]' , array(
		'description' => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
		'label'       => esc_html__( 'Call Number', 'decree-pro' ),
		'section'     => 'decree_header_right',
		'settings'    => 'decree_theme_options[header_right_call_number]',
	)
);

$wp_customize->add_setting( 'decree_theme_options[header_right_button_text]', array(
	'default'			=> $defaults['header_right_button_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'decree_theme_options[header_right_button_text]', array(
	'description' => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
	'label'       => esc_html__( 'Button Text', 'decree-pro' ),
	'section'     => 'decree_header_right',
	'settings'    => 'decree_theme_options[header_right_button_text]',
) );

$wp_customize->add_setting( 'decree_theme_options[header_right_button_link]', array(
	'default'			=> $defaults['header_right_button_link'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'decree_theme_options[header_right_button_link]', array(
	'description' => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
	'label'       => esc_html__( 'Button Link', 'decree-pro' ),
	'section'     => 'decree_header_right',
	'settings'    => 'decree_theme_options[header_right_button_link]',
) );

$wp_customize->add_setting( 'decree_theme_options[header_right_button_link_target]', array(
	'default'			=> $defaults['header_right_button_link_target'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[header_right_button_link_target]', array(
	'label'    	=> esc_html__( 'Check to Open Link in New Window/Tab', 'decree-pro' ),
	'section'     => 'decree_header_right',
	'settings'    => 'decree_theme_options[header_right_button_link_target]',
	'type'        => 'checkbox',
) );
// Header Right Sidebar Option End

// Header Top
$wp_customize->add_section( 'decree_header_top', array(
	'panel'			=> 'decree_theme_options',
	'description'	=> esc_html__( 'Header Top Options', 'decree-pro' ),
	'priority' 		=> 208.5,
	'title'    		=> esc_html__( 'Header Top Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[fixed_header_top]', array(
	'default'			=> $defaults['fixed_header_top'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[fixed_header_top]', array(
	'label'    			=> esc_html__( 'Check to fix the positon of header top', 'decree-pro' ),
	'section'  			=> 'decree_header_top',
	'settings' 			=> 'decree_theme_options[fixed_header_top]',
	'type'	   			=> 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[disable_date]', array(
	'default'			=> $defaults['disable_date'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[disable_date]', array(
	'label'    => esc_html__( 'Check to disable date', 'decree-pro' ),
	'section'  => 'decree_header_top',
	'settings' => 'decree_theme_options[disable_date]',
	'type'	   => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[disable_social_icons]', array(
	'default'			=> $defaults['disable_social_icons'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[disable_social_icons]', array(
	'label'    			=> esc_html__( 'Check to disable social icons', 'decree-pro' ),
	'section'  			=> 'decree_header_top',
	'settings' 			=> 'decree_theme_options[disable_social_icons]',
	'type'	   			=> 'checkbox',
) );
// Header Top End

// Homepage / Frontpage Options.
$wp_customize->add_section( 'decree_homepage_options', array(
	'panel'           => 'decree_theme_options',
	'priority'        => 209,
	'title'           => esc_html__( 'Homepage / Frontpage Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[disable_homepage_content]', array(
	'default'			=> $defaults['disable_homepage_content'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[disable_homepage_content]', array(
	'label'		=> esc_html__( 'Check to disable Homepage/Frontpage Content', 'decree-pro' ),
	'section'   => 'decree_homepage_options',
	'settings'  => 'decree_theme_options[disable_homepage_content]',
	'type'		=> 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[front_page_title]', array(
	'default'           => $defaults['front_page_title'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[front_page_title]' , array(
		'description'     => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
		'label'           => esc_html__( 'Latest Posts Title', 'decree-pro' ),
		'section'         => 'decree_homepage_options',
		'settings'        => 'decree_theme_options[front_page_title]',
	)
);

$wp_customize->add_setting( 'decree_theme_options[front_page_description]', array(
	'default'           => $defaults['front_page_description'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[front_page_description]' , array(
		'description'     => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
		'label'           => esc_html__( 'Latest Posts Description', 'decree-pro' ),
		'section'         => 'decree_homepage_options',
		'settings'        => 'decree_theme_options[front_page_description]',
	)
);

$wp_customize->add_setting( 'decree_theme_options[front_page_category]', array(
	'default'			=> $defaults['front_page_category'],
	'sanitize_callback'	=> 'decree_sanitize_category_list',
) );

$wp_customize->add_control( new decree_Customize_Dropdown_Categories_Control( $wp_customize, 'decree_theme_options[front_page_category]', array(
	'description'     => esc_html__( 'Only posts that belong to the categories selected here will be displayed on the posts page', 'decree-pro' ),
	'label'           => esc_html__( 'Select Categories', 'decree-pro' ),
	'name'            => 'decree_theme_options[front_page_category]',
	'section'         => 'decree_homepage_options',
	'settings'        => 'decree_theme_options[front_page_category]',
	'type'            => 'dropdown-categories',
) ) );
// Homepage / Frontpage Settings End.

// Layout Options.
$wp_customize->add_section( 'decree_layout', array(
	'panel'    => 'decree_theme_options',
	'priority' => 211,
	'title'    => esc_html__( 'Layout Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[theme_layout]', array(
	'default'			=> $defaults['theme_layout'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[theme_layout]', array(
	'choices'  => decree_layouts(),
	'label'    => esc_html__( 'Default Layout', 'decree-pro' ),
	'section'  => 'decree_layout',
	'settings' => 'decree_theme_options[theme_layout]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[homepage_layout]', array(
	'default'			=> $defaults['homepage_layout'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[homepage_layout]', array(
	'choices'  => decree_layouts(),
	'label'    => esc_html__( 'Home/Archive Page Layout', 'decree-pro' ),
	'section'  => 'decree_layout',
	'settings' => 'decree_theme_options[homepage_layout]',
	'type'     => 'select',
) );

if ( class_exists( 'WooCommerce' ) ) {
	$wp_customize->add_setting( 'decree_theme_options[woocommerce_layout]', array(
		'default'			=> $defaults['woocommerce_layout'],
		'sanitize_callback' => 'decree_sanitize_select',
	) );

	$wp_customize->add_control( 'decree_theme_options[woocommerce_layout]', array(
		'choices'	=> decree_layouts(),
		'label'		=> esc_html__( 'Woocommerce Layout', 'decree-pro' ),
		'section'	=> 'decree_layout',
		'settings'   => 'decree_theme_options[woocommerce_layout]',
		'type'		=> 'select',
	) );
}

$wp_customize->add_setting( 'decree_theme_options[content_layout]', array(
	'default'			=> $defaults['content_layout'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[content_layout]', array(
	'choices'   => decree_get_archive_content_layout(),
	'label'		=> esc_html__( 'Archive Content Layout', 'decree-pro' ),
	'section'   => 'decree_layout',
	'settings'  => 'decree_theme_options[content_layout]',
	'type'      => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[single_post_image_layout]', array(
	'default'			=> $defaults['single_post_image_layout'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[single_post_image_layout]', array(
		'label'		=> esc_html__( 'Single Page/Post Image Layout ', 'decree-pro' ),
		'section'   => 'decree_layout',
		'settings'  => 'decree_theme_options[single_post_image_layout]',
		'type'	  	=> 'select',
		'choices'  	=> decree_image_sizes_options(),
) );
	// Layout Options End

// Pagination Options
$pagination_type	= $options['pagination_type'];

$nav_desc = '';

/**
* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
*/
$nav_desc = sprintf(
	wp_kses(
		__( 'Infinite Scroll Options requires %1$sJetPack Plugin%2$s with Infinite Scroll module Enabled.', 'decree-pro' ),
		array(
			'a' => array(
				'href' => array(),
				'target' => array(),
			),
			'br'=> array()
		)
	),
	'<a target="_blank" href="https://wordpress.org/plugins/jetpack/">',
	'</a>'
);

$nav_desc .= '&nbsp;' . sprintf(
	wp_kses(
		__( 'Once Jetpack is installed, Infinite Scroll Settings can be found %1$shere%2$s', 'decree-pro' ),
		array(
			'a' => array(
				'href' => array(),
				'target' => array(),
			),
			'br'=> array()
		)
	),
	'<a target="_blank" href="' . esc_url( admin_url( 'admin.php?page=jetpack#/settings' ) ) . '">',
	'</a>'
);

$wp_customize->add_section( 'decree_pagination_options', array(
	'description'	=> $nav_desc,
	'panel'  		=> 'decree_theme_options',
	'priority'		=> 212,
	'title'    		=> esc_html__( 'Pagination Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[pagination_type]', array(
	'default'			=> $defaults['pagination_type'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'decree_theme_options[pagination_type]', array(
	'choices'  => decree_get_pagination_types(),
	'label'    => esc_html__( 'Pagination type', 'decree-pro' ),
	'section'  => 'decree_pagination_options',
	'settings' => 'decree_theme_options[pagination_type]',
	'type'	   => 'select',
) );
// Pagination Options End


// Scrollup
$wp_customize->add_section( 'decree_scrollup', array(
	'panel'    => 'decree_theme_options',
	'priority' => 215,
	'title'    => esc_html__( 'Scrollup Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[disable_scrollup]', array(
	'default'			=> $defaults['disable_scrollup'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[disable_scrollup]', array(
	'label'		=> esc_html__( 'Check to disable Scroll Up', 'decree-pro' ),
	'section'   => 'decree_scrollup',
	'settings'  => 'decree_theme_options[disable_scrollup]',
	'type'		=> 'checkbox',
) );
// Scrollup End

// Search Options
$wp_customize->add_section( 'decree_search_options', array(
	'description'=> esc_html__( 'Change default placeholder text in Search.', 'decree-pro'),
	'panel'  => 'decree_theme_options',
	'priority' => 216,
	'title'    => esc_html__( 'Search Options', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[search_text]', array(
	'default'			=> $defaults['search_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'decree_theme_options[search_text]', array(
	'label'		=> esc_html__( 'Default Display Text in Search', 'decree-pro' ),
	'section'   => 'decree_search_options',
	'settings'  => 'decree_theme_options[search_text]',
	'type'		=> 'text',
) );
// Search Options End

// Single Post Navigation
$wp_customize->add_section( 'decree_single_post_navigation', array(
	'panel'  => 'decree_theme_options',
	'priority' => 217,
	'title'    => esc_html__( 'Single Post Navigation', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[disable_single_post_navigation]', array(
	'default'			=> $defaults['disable_single_post_navigation'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[disable_single_post_navigation]', array(
	'label'		=> esc_html__( 'Check to disable Single Post Navigation', 'decree-pro' ),
	'section'   => 'decree_single_post_navigation',
	'settings'  => 'decree_theme_options[disable_single_post_navigation]',
	'type'		=> 'checkbox',
) );
// Single Post Navigation End

// Update Notifier
$wp_customize->add_section( 'decree_update_notifier', array(
	'title'    => esc_html__( 'Update Notifier', 'decree-pro' ),
	'priority' => 217,
	'panel'    => 'decree_theme_options',
) );

$wp_customize->add_setting( 'decree_theme_options[update_notifier]', array(
	'default'			=> $defaults['update_notifier'],
	'sanitize_callback' => 'decree_sanitize_checkbox',
) );

$wp_customize->add_control( 'decree_theme_options[update_notifier]', array(
	'label'		=> esc_html__( 'Check to disable update notifications', 'decree-pro' ),
	'section'   => 'decree_update_notifier',
	'settings'  => 'decree_theme_options[update_notifier]',
	'type'		=> 'checkbox',
) );
// Update Notifier End
